@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -10,6 +10,7 @@ our @EXPORT_OK = qw(
     layout checkerboard animate
     chess checkers conway
     calculator dk shroom
+    banner
 );
 
 use Clone;
@@ -26,15 +27,16 @@ sub east    { generate( @_, theta =>   90, tgroups => 0, pinhead => 1 ) }
 sub south   { generate( @_, theta => -180, tgroups => 0, pinhead => 1 ) }
 sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
-sub layout          { Spreadsheet::HTML::Presets::layout( @_ ) }
-sub conway          { Spreadsheet::HTML::Presets::conway( @_ ) }
-sub calculator      { Spreadsheet::HTML::Presets::calculator( @_ ) }
-sub chess           { Spreadsheet::HTML::Presets::chess( @_ ) }
-sub checkers        { Spreadsheet::HTML::Presets::checkers( @_ ) }
-sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard( @_ ) }
-sub animate         { Spreadsheet::HTML::Presets::animate( @_ ) }
-sub dk              { Spreadsheet::HTML::Presets::dk( @_ ) }
-sub shroom          { Spreadsheet::HTML::Presets::shroom( @_ ) }
+sub layout          { Spreadsheet::HTML::Presets::layout(           @_ ) }
+sub conway          { Spreadsheet::HTML::Presets::conway(           @_ ) }
+sub calculator      { Spreadsheet::HTML::Presets::calculator(       @_ ) }
+sub chess           { Spreadsheet::HTML::Presets::chess(            @_ ) }
+sub checkers        { Spreadsheet::HTML::Presets::checkers(         @_ ) }
+sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
+sub animate         { Spreadsheet::HTML::Presets::animate(          @_ ) }
+sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
+sub dk              { Spreadsheet::HTML::Presets::dk(               @_ ) }
+sub shroom          { Spreadsheet::HTML::Presets::shroom(           @_ ) }
 
 sub generate {
     my %args = _process( @_ );
@@ -335,7 +337,7 @@ Spreadsheet::HTML - Just another HTML table generator.
 
     # non OO
     use Spreadsheet::HTML qw( portrait landscape );
-    print portrait( $data, td => sub { sprintf "%02d, shift } );
+    print portrait( $data, td => sub { sprintf "%02d", shift } );
     print landscape( $data, tr => { class => [qw(odd even)] } );
 
 =head1 DESCRIPTION
@@ -435,6 +437,8 @@ with little to no additional coding.
 
 =item * C<animate( direction, %params )>
 
+=item * C<banner( text, font, %params )>
+
 =item * C<chess( %params )>
 
 =item * C<checkers( %params )>
