@@ -13,6 +13,9 @@ our $NO_SPECTRUM = $@;
 eval "use JavaScript::Minifier";
 our $NO_MINIFY = $@;
 
+eval "use Text::FIGlet";
+our $NO_FIGLET = $@;
+
 sub layout {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -87,6 +90,56 @@ sub animate {
     return $js . $table;
 }
 
+sub banner {
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
+    my @cells = ();
+    unless ($NO_FIGLET) {
+
+        my @banner;
+        eval {
+            @banner = Text::FIGlet
+                ->new( -d => $args->{dir}, -f => $args->{emboss} ? 'block' : 'banner' )
+                ->figify( -A => uc( $args->{text} ) );
+        };
+
+        if (@banner) {
+            push @cells, ( fill => join 'x', scalar( @banner ), length( $banner[0] ) );
+            my $on  = $args->{on}  || 'black';
+            my $off = $args->{off} || 'white';
+
+            for my $row (0 .. $#banner) {
+                my @line = split //, $banner[$row];
+                for my $col (0 .. $#line) {
+                    my $key = sprintf '-row%scol%s', $row, $col;
+                    if ($args->{emboss}) {
+                        if ($line[$col] eq ' ') {
+                            push @cells, ( $key => { style => { 'background-color' => $off } } );
+                        } elsif ($line[$col] eq '_') {
+                            push @cells, ( $key => { style => { 'background-color' => $off, 'border-bottom' => "1px solid $on" } } );
+                        } else {
+                            push @cells, ( $key => { style => { 'background-color' => $off, 'border-left' => "1px solid $on" } } );
+                        }
+                    } else {
+                        my $color = $line[$col] eq ' ' ? $off : $on;
+                        push @cells, ( $key => { style => { 'background-color' => $color } } );
+                    }
+                }
+            }
+        }
+    }
+
+    my @args = (
+        @_,
+        @cells,
+    );
+
+    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+    return $table;
+}
+
 sub calculator {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -190,26 +243,17 @@ sub conway {
 sub checkers {
     my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
 
-    my @rows;
-    $rows[0] = [ '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;' ];
-    $rows[1] = [ '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '' ];
-    $rows[2] = [ '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;' ];
-    $rows[5] = [ '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '' ];
-    $rows[6] = [ '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;' ];
-    $rows[7] = [ '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '' ];
+    my @data = (
+        [ '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;' ],
+        [ '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '' ],
+        [ '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;', '', '&#9922;' ],
+        [], [],
+        [ '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '' ],
+        [ '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;' ],
+        [ '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '', '&#9920;', '' ],
+    );
 
     my @args = (
-        tgroups  => 0,
-        headless => 0,
-        pinhead  => 0,
-        matrix   => 1,
-        -row0 => sub { shift @{ $rows[0] } },
-        -row1 => sub { shift @{ $rows[1] } },
-        -row2 => sub { shift @{ $rows[2] } },
-        -row5 => sub { shift @{ $rows[5] } },
-        -row6 => sub { shift @{ $rows[6] } },
-        -row7 => sub { shift @{ $rows[7] } },
-        fill  => '8x8',
         table => {
             width => '65%',
             style => {
@@ -227,6 +271,12 @@ sub checkers {
             }
         },
         @_,
+        tgroups  => 0,
+        headless => 0,
+        pinhead  => 0,
+        matrix   => 1,
+        fill     => '8x8',
+        data     => \@data,
     );
 
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
@@ -235,19 +285,15 @@ sub checkers {
 sub chess {
     my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
 
-    my @black = ( '&#9820;', '&#9822;', '&#9821;', '&#9819;', '&#9818;', '&#9821;', '&#9822;', '&#9820;' );
-    my @white = ( '&#9814;', '&#9816;', '&#9815;', '&#9813;', '&#9812;', '&#9815;', '&#9816;', '&#9814;' );
+    my @data = (
+        [ '&#9820;', '&#9822;', '&#9821;', '&#9819;', '&#9818;', '&#9821;', '&#9822;', '&#9820;' ],
+        [ '&#9823;', '&#9823;', '&#9823;', '&#9823;', '&#9823;', '&#9823;', '&#9823;', '&#9823;' ],
+        [], [], [], [],
+        [ '&#9817;', '&#9817;', '&#9817;', '&#9817;', '&#9817;', '&#9817;', '&#9817;', '&#9817;' ],
+        [ '&#9814;', '&#9816;', '&#9815;', '&#9813;', '&#9812;', '&#9815;', '&#9816;', '&#9814;' ],
+    );
 
     my @args = (
-        tgroups  => 0,
-        headless => 0,
-        pinhead  => 0,
-        matrix   => 1,
-        -row0 => sub { shift @black },
-        -row1 => sub {'&#9823;'},
-        -row6 => sub {'&#9817;'},
-        -row7 => sub { shift @white },
-        fill  => '8x8',
         table => {
             width => '65%',
             style => {
@@ -265,6 +311,12 @@ sub chess {
             }
         },
         @_,
+        tgroups  => 0,
+        headless => 0,
+        pinhead  => 0,
+        matrix   => 1,
+        fill     => '8x8',
+        data     => \@data,
     );
 
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
@@ -488,6 +540,16 @@ Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
 via L<Javascript::Minifier> if it is installed.
 
+=item * C<banner( dir, text, emboss, on, off, %params )>
+
+Will generate and display a banner using the given C<text> in the
+'banner' font. Set C<emboss> to a true value and the font 'block'
+will be emulated by highlighting the left and bottom borders of the cell.
+Set the foreground color with C<on> and the background with C<off>.
+You Must have L<Text::FIGlet> installed in order to use this preset.
+
+  banner( dir => '/path/to/figlet/fonts', text => 'HI', on => 'red' )
+
 =item * C<conway( on, off, fade, interval, jquery, %params )>
 
 Game of life. From an implementation i wrote back in college.
